@@ -15,8 +15,13 @@ lavSampleStatsFromData <- function(Data          = NULL,
                                    meanstructure = FALSE,
                                    WLS.V         = NULL,
                                    NACOV         = NULL,
+                                   ridge         = 1e-5,
+                                   debug         = FALSE,
                                    verbose       = FALSE) {
 
+    # ridge default
+    ridge.eps <- 0.0
+
     # get X and Mp
     if(!is.null(Data)) {
         X <- Data@X; Mp <- Data@Mp
@@ -125,7 +130,7 @@ lavSampleStatsFromData <- function(Data          = NULL,
                               eXo=Data@eXo[[g]], ## FIXME, will not work with bootstrap
                               group = g, # for error messages only
                               WLS.W = WLS.W,
-                              verbose=FALSE)
+                              verbose=debug)
             if(verbose) cat("done\n")
             # if (and only if) all variables are ordinal, store pairwise
             # tables
@@ -175,16 +180,27 @@ lavSampleStatsFromData <- function(Data          = NULL,
         
             # icov and cov.log.det (but not if missing)
             if(is.null(Mp[[g]])) {
-                tmp <- try(inv.chol(cov[[g]], logdet=TRUE))
+                tmp <- try(inv.chol(cov[[g]], logdet=TRUE), silent=TRUE)
                 if(inherits(tmp, "try-error")) {
                     if(ngroups > 1) {
                         warning("lavaan WARNING sample covariance can not be inverted in group: ", g)
                     } else {
                         warning("lavaan WARNING: sample covariance can not be inverted")
                     }
-                    # emergency values
-                    icov[[g]] <- MASS:::ginv(cov[[g]])
-                    cov.log.det[[g]] <- log(.Machine$double.eps)
+                    # ok, try ridging for exogenous x only
+                    ## FIXME -- only x (but all for now)
+                    ridge.eps <- ridge
+                    diag(cov[[g]]) <- diag(cov[[g]]) + ridge.eps
+                    tmp <- try(inv.chol(cov[[g]], logdet=TRUE), silent=TRUE)
+                    if(inherits(tmp, "try-error")) {
+                        # emergency values
+                        icov[[g]] <- MASS:::ginv(cov[[g]])
+                        cov.log.det[[g]] <- log(.Machine$double.eps)
+                    } else {
+                        cov.log.det[[g]] <- attr(tmp, "logdet")
+                        attr(tmp, "logdet") <- NULL
+                        icov[[g]]        <- tmp
+                    }
                 } else {
                     cov.log.det[[g]] <- attr(tmp, "logdet")
                     attr(tmp, "logdet") <- NULL
@@ -334,6 +350,7 @@ lavSampleStatsFromData <- function(Data          = NULL,
                        # extra sample statistics
                        icov         = icov,
                        cov.log.det  = cov.log.det,
+                       ridge        = ridge.eps,
                        WLS.obs      = WLS.obs,
                        WLS.V        = WLS.V,                     
                        NACOV        = NACOV,
@@ -357,8 +374,12 @@ lavSampleStatsFromMoments <- function(sample.cov    = NULL,
                                       mimic         = "lavaan",
                                       WLS.V         = NULL,
                                       NACOV         = NULL,
+                                      ridge         = 1e-5,
                                       meanstructure = FALSE) {
 
+    # ridge default
+    ridge.eps <- 0.0
+
     # matrix -> list
     if(!is.list(sample.cov)) sample.cov  <- list(sample.cov)
     if(!is.null(sample.mean) && !is.list(sample.mean))
@@ -484,12 +505,26 @@ lavSampleStatsFromMoments <- function(sample.cov    = NULL,
         }
 
         # icov and cov.log.det
-        tmp <- try(inv.chol(cov[[g]], logdet=TRUE))
+        tmp <- try(inv.chol(cov[[g]], logdet=TRUE), silent=TRUE)
         if(inherits(tmp, "try-error")) {
             if(ngroups > 1) {
-                stop("lavaan ERROR: sample covariance can not be inverted in group: ", g)
+                warning("lavaan WARNING sample covariance can not be inverted in group: ", g)
             } else {
-                stop("lavaan ERROR: sample covariance can not be inverted")
+                warning("lavaan WARNING: sample covariance can not be inverted")
+            }
+            # ok, try ridging for exogenous x only
+            ## FIXME -- only x (but all for now)
+            ridge.eps <- ridge
+            diag(cov[[g]]) <- diag(cov[[g]]) + ridge.eps
+            tmp <- try(inv.chol(cov[[g]], logdet=TRUE), silent=TRUE)
+            if(inherits(tmp, "try-error")) {
+                # emergency values
+                icov[[g]] <- MASS:::ginv(cov[[g]])
+                cov.log.det[[g]] <- log(.Machine$double.eps)
+            } else {
+                cov.log.det[[g]] <- attr(tmp, "logdet")
+                attr(tmp, "logdet") <- NULL
+                icov[[g]]        <- tmp
             }
         } else {
             cov.log.det[[g]] <- attr(tmp, "logdet")
@@ -556,6 +591,7 @@ lavSampleStatsFromMoments <- function(sample.cov    = NULL,
                        # extra sample statistics
                        icov         = icov,
                        cov.log.det  = cov.log.det,
+                       ridge        = ridge.eps,
                        WLS.obs      = WLS.obs,
                        WLS.V        = WLS.V,
                        NACOV        = NACOV,
