@@ -30,11 +30,13 @@ simulateData <- function(
                          kurtosis        = NULL,
 
                          # control
-                         seed = NULL,
-                         empirical = FALSE,
+                         seed            = NULL,
+                         empirical       = FALSE,
 
-                         return.type = "data.frame",
-                         return.fit = FALSE
+                         return.type     = "data.frame",
+                         return.fit      = FALSE,
+                         debug           = FALSE,
+                         standardized    = FALSE
                         )
 {
     if(!is.null(seed)) set.seed(seed)
@@ -57,6 +59,11 @@ simulateData <- function(
                      auto.cov.y=auto.cov.y,
                      ngroups=length(sample.nobs))
 
+    if(debug) {
+        cat("initial lav\n")
+        print(as.data.frame(lav))
+    }
+
     # fill in any remaining NA values (needed for unstandardize)
     # 1 for variances and factor loadings, 0 otherwise
     idx <- which(lav$op == "=~" & is.na(lav$ustart))
@@ -66,6 +73,48 @@ simulateData <- function(
     idx <- which(is.na(lav$ustart))
     if(length(idx) > 0L) lav$ustart[idx] <- 0.0
 
+    # set residual variances to enforce a standardized solution
+    # but only if no residual variances have been specified in the syntax
+    
+    if(standardized) {
+        # check if factor loadings are smaller than 1.0
+        lambda.idx <- which(lav$op == "=~")
+        if(any(lav$ustart[lambda.idx] >= 1.0)) {
+            warning("lavaan WARNING: standardized=TRUE but factor loadings are >= 1.0")
+        }
+
+        # check if regression coefficients are smaller than 1.0
+        reg.idx <- which(lav$op == "~")
+        if(any(lav$ustart[reg.idx] >= 1.0)) {
+            warning("lavaan WARNING: standardized=TRUE but regression coefficients are >= 1.0")
+        }
+
+        # for ordered observed variables, we will get '0.0', but that is ok
+        # so there is no need to make a distinction between numeric/ordered 
+        # here??
+        lav2 <- lav
+        ngroups <- max(lav$group)
+        ov.names <- vnames(lav, "ov")
+        ov.var.idx <- which(lav$op == "~~" & lav$lhs %in% ov.names & 
+                            lav$rhs == lav$lhs)
+        if(any(lav2$user[ov.var.idx] > 0L)) {
+            warning("lavaan WARNING: if residual variances are specified, please use standardized=FALSE")
+        }
+        lav2$ustart[ov.var.idx] <- 0.0
+        fit <- lavaan(model=lav2, sample.nobs=sample.nobs,  ...)
+        Sigma.hat <- computeSigmaHat(fit@Model)
+        for(g in 1:ngroups) {
+            var.group <- which(lav$op == "~~" & lav$lhs %in% ov.names & 
+                               lav$rhs == lav$lhs & lav$group == g)
+            lav$ustart[var.group] <- 1 - diag(Sigma.hat[[g]])
+        }
+
+        if(debug) {
+            cat("after standardisation lav\n")
+            print(as.data.frame(lav))
+        }    
+    }
+
 
     # unstandardize 
     if(!is.null(ov.var)) {
@@ -75,21 +124,28 @@ simulateData <- function(
         lav$ustart <- unstandardize.est.ov(partable=lav, ov.var=ov.var)
 
         # 2. unstandardized latent variables
+
+        if(debug) {
+            cat("after unstandardisation lav\n")
+            print(as.data.frame(lav))
+        }
     }
 
-
-    # basic fit (ignoring thresholds
-    ord.idx <- which(lav$op == "|")
-    if(length(ord.idx) > 0L) {
-        lav.no_ord <- lav[-ord.idx,]
-    } else {
-        lav.no_ord <- lav
-    }
-    fit <- lavaan(model=lav.no_ord, sample.nobs=sample.nobs,  ...)
+    # fit the model without data
+    fit <- lavaan(model=lav, sample.nobs=sample.nobs,  ...)
 
     # the model-implied moments for the population
     Sigma.hat <- computeSigmaHat(fit@Model)
        Mu.hat <- computeMuHat(fit@Model)
+    if(fit@Model@categorical) {
+       TH <- computeTH(fit@Model)
+    }
+
+    if(debug) {
+        print(Sigma.hat)
+        print(Mu.hat)
+        if(exists("TH")) print(TH)
+    }
 
     # ngroups
     ngroups <- length(sample.nobs)
@@ -112,7 +168,7 @@ simulateData <- function(
                                   skewness = skewness,  # FIXME: per group?
                                   kurtosis = kurtosis)
             # rescale
-            X[[g]] <- scale(Z, center = Mu.hat[[g]],
+            X[[g]] <- scale(Z, center = -Mu.hat[[g]],
                                scale  = 1/sqrt(diag(Sigma.hat[[g]])))
         }
 
@@ -120,14 +176,12 @@ simulateData <- function(
         ov.ord <- vnames(lav, type="ov.ord", group=g)
         if(length(ov.ord) > 0L) {
             ov.names <- vnames(lav, type="ov", group=g)
-            # use thresholds to cut -- after standardization?
+            # use thresholds to cut
             for(o in ov.ord) {
                 o.idx <- which(o == ov.names)
-                th.idx <- which(lav$op == "|" & lav$lhs == o)
-                th.val <- c(-Inf,sort(lav$ustar[th.idx]),+Inf)
-                # scale!!
-                xz <- scale(X[[g]][,o.idx])
-                X[[g]][,o.idx] <- as.integer(cut(xz, th.val))
+                th.idx <- which(lav$op == "|" & lav$lhs == o & lav$group == g)
+                th.val <- c(-Inf,sort(lav$ustart[th.idx]),+Inf)
+                X[[g]][,o.idx] <- as.integer(cut(X[[g]][,o.idx], th.val))
             }
         }
 
