@@ -424,98 +424,3 @@ steepest.descent <- function(start, objective, gradient, iter.max, verbose) {
     x
 }
 
-write.raw.data <- function(data, file="data", 
-                           na.rm=TRUE, labels=FALSE, std.ov=FALSE)
-{
-    # listwise deletion?
-    if(na.rm) {
-        data <- na.omit(data)
-    }
-
-    # standardize observed variables?
-    if(std.ov) {
-        data <- scale(data)[,]
-    }
-
-    # write data in raw format (suitable for lisrel and mplus)
-    dfile <- paste(file, ".raw", sep="")
-    write.table(data, file=dfile, na="-999999",
-                col.names=F, row.names=F, quote=F)
-
-    # write labels to file
-    if(labels) {
-        lfile <-  paste(file, ".lab", sep="")
-        write.table(unique(names(data)), file=lfile, row.names=F,
-                    col.names=F, quote=F)
-    }
-}
-
-# this is primitive: no 'fixed' values, no equal statements, etc...
-mm2mplus <- function(x, pre="\t\t\t") {
-
-    out <- ""
-    for(i in 1:length(x)) {
-        out <- paste(out, pre, 
-                     names(x)[i], 
-                     " BY ", 
-                     paste(all.vars(x[[i]]), collapse=" "), ";\n", sep="")
-    }
-
-    out
-}
- 
-
-eqs2mplus <- function(x, pre="\t\t\t") {
-
-    out <- ""
-    for(i in 1:length(x)) {
-        out <- paste(out, pre,
-                     paste(all.vars(x[[i]][[2]])),
-                     " ON ",
-                     paste(all.vars(x[[i]][[3]]), collapse=" "), ";\n", sep="")
-    }
-    
-    out
-}
-
-vc2mplus <- function(x, pre="\t\t\t") {
-
-    out <- ""
-    for(i in 1:length(x)) {
-        out <- paste(out, pre,
-                     all.vars(x[[i]][[2]]),
-                     " WITH ",
-                     paste(all.vars(x[[i]][[3]]), collapse=" "), ";\n", sep="")
-    }
-
-    out
-
-}
-
-int2mplus <- function(x, pre="\t\t\t") {
-
-    out <- ""
-    for(i in 1:length(x)) {
-        out <- paste(out, pre,
-                     "[",all.vars(x[[i]][[2]]),"]",";\n", sep="")
-    }
-
-    out
-}
-
-read.prelis.acm <- function(file="") {
-
-    # the first three numbers are not needed?
-    raw <- readBin(file, what="double", n=100000)[-c(1,2,3)]
-
-    # guess dimensions
-    n <- length(raw)
-    p <- (sqrt(1 + 8*n)-1)/2
-
-    W <- matrix(0, p, p)
-    W[lower.tri(W, diag=TRUE)] <- raw
-
-    W
-
-}
-
